package de.intevation.flys.artifacts.model;

import de.intevation.flys.artifacts.cache.CacheFactory;

import de.intevation.flys.backend.SessionHolder;

import net.sf.ehcache.Cache;
import net.sf.ehcache.Element;

import org.apache.log4j.Logger;

import org.hibernate.Session;

public class FixingsOverviewFactory
{
    private static Logger log = Logger.getLogger(FixingsOverviewFactory.class);

    public static final String CACHE_NAME = "fixings-overviews";

    private FixingsOverviewFactory() {
    }


    public static FixingsOverview getOverview(String river) {

        log.debug("Looking for fixings overview for river '" + river + "'");

        Cache cache = CacheFactory.getCache(CACHE_NAME);

        if (cache == null) {
            return getUncached(river);
        }

        String key = "fix-over-" + river;

        Element element = cache.get(key);

        if (element != null) {
            return (FixingsOverview)element.getValue();
        }

        FixingsOverview overview = getUncached(river);

        if (overview != null) {
            element = new Element(key, overview);
            cache.put(element);
        }

        return overview;
    }

    public static FixingsOverview getUncached(String river) {
        FixingsOverview overview = new FixingsOverview(river);

        Session session = SessionHolder.HOLDER.get();

        return overview.load(session) ? overview : null;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
